//---------------------------------------------------------------------------
/*
Polymorphic Route Manager.
This software controls polymorph structures of MSTS routes
(makes routes polymorphic).
To get full information about this software see documentation.
Copyright  2010 ASRRGlobal Team.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.

http://asrr.ucoz.com/
asrr.ucoz.com@mail.ru
djafsar@mail.com
*/
//---------------------------------------------------------------------------
// MainForm
//---------------------------------------------------------------------------

#include <vcl.h>
#include <stdio.h>
#pragma hdrstop

#include <registry.hpp>

#include "main.h"
#include "about.h"
#include "cfgw.h"
#include "report.h"

// #include "Functions.c" // Commented cause there are errors in it...
// prm1.cpp - for OpenFile at cursor (for quick developing ;))
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma link "Trayicon"
#pragma resource "*.dfm"
TMainForm *MainForm;
//---------------------------------------------------------------------------
__fastcall TMainForm::TMainForm(TComponent* Owner)
        : TForm(Owner)
{     
        // Defining PRM paths
        // GlPRMPath contains a basic independed data, that can`t be defined from PRM`s configuration.
        GlPRMPath               = ExtractFilePath(Application->ExeName); // Don`t use GetCurrentDir() cause this function returns System CurrentDir value (environment variable)!
        // Other PRM`s paths
        GlPRMCFGPath            = GlPRMPath + "cfg\\";
        GlPRMCrashRepPath       = GlPRMPath + "crashreports\\";
        GlPRMCursorsPath        = GlPRMPath + "cur\\";
        GlPRMHelpPath           = GlPRMPath + "help\\";
        GlPRMIconsPath          = GlPRMPath + "ico\\";
        GlPRMTrayAnimIconPath   = GlPRMIconsPath + "tray\\"; // Same as 'GlPRMPath + "ico\\tray\\";'
        GlPRMImgPath            = GlPRMPath + "img\\";
        GlPRMImgBtnPath         = GlPRMImgPath + "btn\\"; // Same as 'GlPRMPath + "img\\btn\\";'
        GlPRMImgRatingPath      = GlPRMImgPath + "rating\\"; // Same as 'GlPRMPath + "img\\rating\\";'
        GlPRMLangPath           = GlPRMPath + "lang\\";
        GlPRMMusicPath          = GlPRMPath + "music\\";
        GlPRMHWMusicPath        = GlPRMMusicPath + "hw\\"; // Same as 'GlPRMPath + "music\\hw\\";'
        GlPRMRepPath            = GlPRMPath + "reports\\";
        GlPRMSoundsPath         = GlPRMPath + "sounds\\";
        GlPRMUpdatesPath        = GlPRMPath + "updates\\";
        // Other constants of PRM`s paths and files (filenames)
        GlReportFile            = GlPRMRepPath + FormatDateTime("yyyy-mm-dd_hh-nn-ss_", Now()) + ChangeFileExt(ExtractFileName(Application->ExeName), "") + "_prm1.n++"; // Full filename of report file for current program run.
        GlUpdateHistoryFile     = GlPRMUpdatesPath + "history.uhf";

        // Loading data from configuration files
        // Prefixes for configuration variables are composed from upper case letters from the configuration`s names of sections by default.
        // Initialization 1, File: mainsetts.ini (Main settings)
        TIniFile *mainsetts;
        mainsetts = new TIniFile(GlPRMPath + "mainsetts.ini");
        // [External]
        CFG_PRM1Filename                = mainsetts->ReadString("External", "PRM1Filename", "prm1.exe"); // PRM1Filename
        CFG_PRM1Starter                 = mainsetts->ReadString("External", "PRM1Starter", "prm1starter1.exe"); // PRM1Starter
        CFG_PRM1StarterBakup            = mainsetts->ReadString("External", "PRM1StarterBakup", "bprms.store"); // PRM1StarterBakup
        CFG_PRM1Path                    = mainsetts->ReadString("External", "PRM1Path", "*") + "\\"; // PRM1Path
        CFG_PRoutePath                  = mainsetts->ReadString("External", "PRoutePath", "*"); // PRoutePath
        CFG_PRM1LangFile                = mainsetts->ReadString("External", "PRM1LangFile", "eng.lng"); // PRM1LangFile
        CFG_PRM1GUICfgMainFile          = mainsetts->ReadString("External", "PRM1GUICfgMainFile", "guicfg") + ".ini"; //PRM1GUICfgMainFile
        CFG_PRM1StdColor                = mainsetts->ReadString("External", "PRM1StdColor", "$00FFFFFF"); // PRM1StdColor
        // [Info]
        CFG_PRouteDirName               = mainsetts->ReadString("Info", "PRouteDirName", "*"); // PRouteDirName
        CFG_PRouteID                    = mainsetts->ReadString("Info", "PRouteID", "*"); // PRouteID
        CFG_PRouteName                  = mainsetts->ReadString("Info", "PRouteName", "*"); // PRouteName
        CFG_PRouteDescription           = mainsetts->ReadString("Info", "PRouteDescription", "*"); // PRouteDescription
        CFG_PRouteFilename              = mainsetts->ReadString("Info", "PRouteFilename", "*"); // PRouteFilename
        CFG_PRouteElectrified           = mainsetts->ReadString("Info", "PRouteElectrified", "*"); // PRouteElectrified
        CFG_PRouteDMountains            = mainsetts->ReadString("Info", "PRouteDMountains", "*"); // PRouteDMountains
        CFG_PRouteSpeedLimit            = mainsetts->ReadString("Info", "PRouteSpeedLimit", "*"); // PRouteSpeedLimit
        CFG_PRouteRestrictedSpeedLimit  = mainsetts->ReadString("Info", "PRouteRestrictedSpeedLimit", "*"); // PRouteRestrictedSpeedLimit
        CFG_PRouteVoltage               = mainsetts->ReadString("Info", "PRouteVoltage", "*"); // PRouteVoltage
        CFG_PRouteVersion               = mainsetts->ReadString("Info", "PRouteVersion", "*"); // PRouteVersion
        CFG_PRouteType                  = mainsetts->ReadString("Info", "PRouteType", "*"); // PRouteType
        CFG_PRouteLength                = mainsetts->ReadString("Info", "PRouteLength", "*"); // PRouteLength
        CFG_PRouteFullLenght            = mainsetts->ReadString("Info", "PRouteFullLenght", "*"); // PRouteFullLenght
        CFG_PRouteTrackLength           = mainsetts->ReadString("Info", "PRouteTrackLength", "*"); // PRouteTrackLength
        CFG_PRouteSeasonsAvailable      = mainsetts->ReadString("Info", "PRouteSeasonsAvailable", "*"); // PRouteSeasonsAvailable
        CFG_PRouteDeveloper             = mainsetts->ReadString("Info", "PRouteDeveloper", "Unknown"); // PRouteDeveloper
        CFG_PRouteBuildDay              = mainsetts->ReadString("Info", "PRouteBuildDay", "*"); // PRouteBuildDay
        CFG_PRouteBuildMonth            = mainsetts->ReadString("Info", "PRouteBuildMonth", "*"); // PRouteBuildMonth
        CFG_PRouteBuildYear             = mainsetts->ReadString("Info", "PRouteBuildYear", "*"); // PRouteBuildYear
        CFG_PRoutePublisher             = mainsetts->ReadString("Info", "PRoutePublisher", "*"); // PRoutePublisher
        CFG_PRouteWebSite               = mainsetts->ReadString("Info", "PRouteWebSite", "*"); // PRouteWebSite
        CFG_PRouteDownloadableLink      = mainsetts->ReadString("Info", "PRouteDownloadableLink", "*"); // PRouteDownloadableLink
        CFG_PRouteCopyright             = mainsetts->ReadString("Info", "PRouteCopyright", "*"); // PRouteCopyright
        CFG_PRouteRFCFTS2Rating         = mainsetts->ReadInteger("Info", "PRouteRFCFTS2Rating", 0); // PRouteRFCFTS2Rating
        CFG_PStructName                 = mainsetts->ReadString("Info", "PStructName", "*"); // PStructName
        CFG_PStructVersion              = mainsetts->ReadString("Info", "PStructVersion", "*"); // PStructVersion
        CFG_PStructDeveloper            = mainsetts->ReadString("Info", "PStructDeveloper", "*"); // PStructDeveloper
        CFG_PStructDate                 = mainsetts->ReadString("Info", "PStructDate", "*"); // PStructDate
        CFG_PStructCopyright            = mainsetts->ReadString("Info", "PStructCopyright", "*"); // PStructCopyright
        CFG_PStructWebSite              = mainsetts->ReadString("Info", "PStructWebSite", "*"); // PStructWebSite
        CFG_PStructUpdateLink           = mainsetts->ReadString("Info", "PStructUpdateLink", "*"); // PStructUpdateLink
        // [PRMConfiguration]
        CFG_defaultsFile                = mainsetts->ReadString("PRMConfiguration", "defaultsFile", "cfgdefs") + ".ini"; // defaultsFile
        CFG_StartupWithOS               = mainsetts->ReadBool("PRMConfiguration", "StartupWithOS", true); // StartupWithOS
        CFG_UseHiddenWhenStartup        = mainsetts->ReadBool("PRMConfiguration", "UseHiddenWhenStartup", false); // UseHiddenWhenStartup
        CFG_UseTrayIcon                 = mainsetts->ReadBool("PRMConfiguration", "UseTrayIcon", true); // UseTrayIcon
        CFG_UseTrayIconInHiddenModeOnly = mainsetts->ReadBool("PRMConfiguration", "UseTrayIconInHiddenModeOnly", true); // UseTrayIconInHiddenModeOnly
        CFG_HideTaskbarButtonInHiddenMode = mainsetts->ReadBool("PRMConfiguration", "HideTaskbarButtonInHiddenMode", true); // HideTaskbarButtonInHiddenMode
        CFG_ReportsAutoClean            = mainsetts->ReadBool("PRMConfiguration", "ReportsAutoClean", false); // ReportsAutoClean
        CFG_AutoCleanWhenReaches        = mainsetts->ReadInteger("PRMConfiguration", "AutoCleanWhenReaches", 50); // AutoCleanWhenReaches
        CFG_UseMainWindowClocks         = mainsetts->ReadBool("PRMConfiguration", "UseMainWindowClocks", true); // UseMainWindowClocks
        CFG_TypeOfClock                 = mainsetts->ReadInteger("PRMConfiguration", "TypeOfClock", 3); // TypeOfClock
        CFG_UseRandomizedTrayicon       = mainsetts->ReadBool("PRMConfiguration", "UseRandomizedTrayicon", false); // UseRandomizedTrayicon
        CFG_RandomizeEveryMinutes       = mainsetts->ReadBool("PRMConfiguration", "RandomizeEveryMinutes", false); // RandomizeEveryMinutes
        CFG_RandomizeMinutesNumber      = mainsetts->ReadInteger("PRMConfiguration", "RandomizeMinutesNumber", 5); // RandomizeMinutesNumber
        CFG_RandomizeOnPRMAction        = mainsetts->ReadBool("PRMConfiguration", "RandomizeOnPRMAction", false); // RandomizeOnPRMAction
        CFG_RandomOnMinResAction        = mainsetts->ReadBool("PRMConfiguration", "RandomOnMinResAction", false); // RandomOnMinResAction
        CFG_RandomOnPolymorphAction     = mainsetts->ReadBool("PRMConfiguration", "RandomOnPolymorphAction", false); // RandomOnPolymorphAction
        CFG_RandomOnAnyOtherAction      = mainsetts->ReadBool("PRMConfiguration", "RandomOnAnyOtherAction", false); // RandomOnAnyOtherAction
        CFG_UseSounds                   = mainsetts->ReadBool("PRMConfiguration", "UseSounds", true); // UseSounds
        CFG_KeepSilence                 = mainsetts->ReadBool("PRMConfiguration", "KeepSilence", true); // KeepSilence
        CFG_SilenceStartTime            = mainsetts->ReadString("PRMConfiguration", "SilenceStartTime", "23:00"); // SilenceStartTime
        CFG_SilenceEndTime              = mainsetts->ReadString("PRMConfiguration", "SilenceEndTime", "09:00"); // SilenceEndTime
        CFG_ClickEvent                  = mainsetts->ReadBool("PRMConfiguration", "ClickEvent", true); // ClickEvent
        CFG_ClickEventFile              = mainsetts->ReadString("PRMConfiguration", "ClickEventFile", "click.wav"); // ClickEventFile
        CFG_MinResEvent                 = mainsetts->ReadBool("PRMConfiguration", "MinResEvent", true); // MinResEvent
        CFG_MinResEventFile             = mainsetts->ReadString("PRMConfiguration", "MinResEventFile", "minres.wav"); // MinResEventFile
        CFG_PolymorphEvent              = mainsetts->ReadBool("PRMConfiguration", "PolymorphEvent", true); // PolymorphEvent
        CFG_PolymorphEventFile          = mainsetts->ReadString("PRMConfiguration", "PolymorphEventFile", "polymorph.wav"); // PolymorphEventFile
        CFG_TimeEventHalfhour           = mainsetts->ReadBool("PRMConfiguration", "TimeEventHalfhour", true); // TimeEventHalfhour
        CFG_TimeEventHalfhourFile       = mainsetts->ReadString("PRMConfiguration", "TimeEventHalfhourFile", "halfhour.wav"); // TimeEventHalfhourFile
        CFG_TimeEventHour               = mainsetts->ReadBool("PRMConfiguration", "TimeEventHour", true); // TimeEventHour
        CFG_TimeEventHourFile           = mainsetts->ReadString("PRMConfiguration", "TimeEventHourFile", "hour.wav"); // TimeEventHourFile
        CFG_BackPolymorphEvent          = mainsetts->ReadBool("PRMConfiguration", "BackPolymorphEvent", true); // BackPolymorphEvent
        CFG_BackPolymorphEventFile      = mainsetts->ReadString("PRMConfiguration", "BackPolymorphEventFile", "backpolymorph.wav"); // BackPolymorphEventFile
        CFG_UseSpecialSoundsFromPStruct = mainsetts->ReadBool("PRMConfiguration", "UseSpecialSoundsFromPStruct", true); // UseSpecialSoundsFromPStruct
        CFG_UseMusic                    = mainsetts->ReadBool("PRMConfiguration", "UseMusic", true); // UseMusic
        CFG_Volume                      = mainsetts->ReadInteger("PRMConfiguration", "Volume", 50); // Volume
        CFG_PlayInHiddenMode            = mainsetts->ReadBool("PRMConfiguration", "PlayInHiddenMode", true); // PlayInHiddenMode
        CFG_HMVolume                    = mainsetts->ReadInteger("PRMConfiguration", "HMVolume", 35); // HMVolume
        CFG_PlaySpecialFiles            = mainsetts->ReadBool("PRMConfiguration", "PlaySpecialFiles", true); // PlaySpecialFiles
        CFG_PSShowFullStatistics        = mainsetts->ReadBool("PRMConfiguration", "PSShowFullStatistics", true); // PSShowFullStatistics
        CFG_PSClaShowFullStatistics     = mainsetts->ReadBool("PRMConfiguration", "PSClaShowFullStatistics", true); // PSClaShowFullStatistics
        CFG_PSAShowFullStatistics       = mainsetts->ReadBool("PRMConfiguration", "PSAShowFullStatistics", true); // PSAShowFullStatistics
        CFG_PSCluShowFullStatistics     = mainsetts->ReadBool("PRMConfiguration", "PSCluShowFullStatistics", true); // PSCluShowFullStatistics
        CFG_PSFShowFullStatistics       = mainsetts->ReadBool("PRMConfiguration", "PSFShowFullStatistics", true); // PSFShowFullStatistics
        CFG_UseProtection               = mainsetts->ReadBool("PRMConfiguration", "UseProtection", false); // UseProtection
        CFG_CheckForUpdates             = mainsetts->ReadBool("PRMConfiguration", "CheckForUpdates", true); // CheckForUpdates
        CFG_CheckForUpdatesPStruct      = mainsetts->ReadBool("PRMConfiguration", "CheckForUpdatesPStruct", true); // CheckForUpdatesPStruct
        CFG_CheckForUpdatesRoute        = mainsetts->ReadBool("PRMConfiguration", "CheckForUpdatesRoute", true); // CheckForUpdatesRoute
        CFG_AutoCheckWhenPRMStarts      = mainsetts->ReadBool("PRMConfiguration", "AutoCheckWhenPRMStarts", true); // AutoCheckWhenPRMStarts
        CFG_DownloadAutomatically       = mainsetts->ReadBool("PRMConfiguration", "DownloadAutomatically", true); // DownloadAutomatically
        CFG_ShowProgressWindow          = mainsetts->ReadBool("PRMConfiguration", "ShowProgressWindow", true); // ShowProgressWindow
        delete mainsetts;
        // Initialization 2, File: cfgdefs.ini (Defaul PRM settings)
        TIniFile *cfgdefs;
        cfgdefs = new TIniFile(GlPRMPath + CFG_defaultsFile);
        // [PRMDefConfiguration]
        CFGDef_defaultsFile                = cfgdefs->ReadString("PRMConfiguration", "defaultsFile", "cfgdefs"); // defaultsFile
        CFGDef_StartupWithOS               = cfgdefs->ReadBool("PRMConfiguration", "StartupWithOS", true); // StartupWithOS
        CFGDef_UseHiddenWhenStartup        = cfgdefs->ReadBool("PRMConfiguration", "UseHiddenWhenStartup", false); // UseHiddenWhenStartup
        CFGDef_UseTrayIcon                 = cfgdefs->ReadBool("PRMConfiguration", "UseTrayIcon", true); // UseTrayIcon
        CFGDef_UseTrayIconInHiddenModeOnly = cfgdefs->ReadBool("PRMConfiguration", "UseTrayIconInHiddenModeOnly", true); // UseTrayIconInHiddenModeOnly
        CFGDef_HideTaskbarButtonInHiddenMode = cfgdefs->ReadBool("PRMConfiguration", "HideTaskbarButtonInHiddenMode", true); // HideTaskbarButtonInHiddenMode
        CFGDef_ReportsAutoClean            = cfgdefs->ReadBool("PRMConfiguration", "ReportsAutoClean", false); // ReportsAutoClean
        CFGDef_AutoCleanWhenReaches        = cfgdefs->ReadInteger("PRMConfiguration", "AutoCleanWhenReaches", 50); // AutoCleanWhenReaches
        CFGDef_UseMainWindowClocks         = cfgdefs->ReadBool("PRMConfiguration", "UseMainWindowClocks", true); // UseMainWindowClocks
        CFGDef_TypeOfClock                 = cfgdefs->ReadInteger("PRMConfiguration", "TypeOfClock", 3); // TypeOfClock
        CFGDef_UseRandomizedTrayicon       = cfgdefs->ReadBool("PRMConfiguration", "UseRandomizedTrayicon", false); // UseRandomizedTrayicon
        CFGDef_RandomizeEveryMinutes       = cfgdefs->ReadBool("PRMConfiguration", "RandomizeEveryMinutes", false); // RandomizeEveryMinutes
        CFGDef_RandomizeMinutesNumber      = cfgdefs->ReadInteger("PRMConfiguration", "RandomizeMinutesNumber", 5); // RandomizeMinutesNumber
        CFGDef_RandomizeOnPRMAction        = cfgdefs->ReadBool("PRMConfiguration", "RandomizeOnPRMAction", false); // RandomizeOnPRMAction
        CFGDef_RandomOnMinResAction        = cfgdefs->ReadBool("PRMConfiguration", "RandomOnMinResAction", false); // RandomOnMinResAction
        CFGDef_RandomOnPolymorphAction     = cfgdefs->ReadBool("PRMConfiguration", "RandomOnPolymorphAction", false); // RandomOnPolymorphAction
        CFGDef_RandomOnAnyOtherAction      = cfgdefs->ReadBool("PRMConfiguration", "RandomOnAnyOtherAction", false); // RandomOnAnyOtherAction
        CFGDef_UseSounds                   = cfgdefs->ReadBool("PRMConfiguration", "UseSounds", true); // UseSounds
        CFGDef_KeepSilence                 = cfgdefs->ReadBool("PRMConfiguration", "KeepSilence", true); // KeepSilence
        CFGDef_SilenceStartTime            = cfgdefs->ReadString("PRMConfiguration", "SilenceStartTime", "23:00"); // SilenceStartTime
        CFGDef_SilenceEndTime              = cfgdefs->ReadString("PRMConfiguration", "SilenceEndTime", "09:00"); // SilenceEndTime
        CFGDef_ClickEvent                  = cfgdefs->ReadBool("PRMConfiguration", "ClickEvent", true); // ClickEvent
        CFGDef_ClickEventFile              = cfgdefs->ReadString("PRMConfiguration", "ClickEventFile", "click.wav"); // ClickEventFile
        CFGDef_MinResEvent                 = cfgdefs->ReadBool("PRMConfiguration", "MinResEvent", true); // MinResEvent
        CFGDef_MinResEventFile             = cfgdefs->ReadString("PRMConfiguration", "MinResEventFile", "minres.wav"); // MinResEventFile
        CFGDef_PolymorphEvent              = cfgdefs->ReadBool("PRMConfiguration", "PolymorphEvent", true); // PolymorphEvent
        CFGDef_PolymorphEventFile          = cfgdefs->ReadString("PRMConfiguration", "PolymorphEventFile", "polymorph.wav"); // PolymorphEventFile
        CFGDef_TimeEventHalfhour           = cfgdefs->ReadBool("PRMConfiguration", "TimeEventHalfhour", true); // TimeEventHalfhour
        CFGDef_TimeEventHalfhourFile       = cfgdefs->ReadString("PRMConfiguration", "TimeEventHalfhourFile", "halfhour.wav"); // TimeEventHalfhourFile
        CFGDef_TimeEventHour               = cfgdefs->ReadBool("PRMConfiguration", "TimeEventHour", true); // TimeEventHour
        CFGDef_TimeEventHourFile           = cfgdefs->ReadString("PRMConfiguration", "TimeEventHourFile", "hour.wav"); // TimeEventHourFile
        CFGDef_BackPolymorphEvent          = cfgdefs->ReadBool("PRMConfiguration", "BackPolymorphEvent", true); // BackPolymorphEvent
        CFGDef_BackPolymorphEventFile      = cfgdefs->ReadString("PRMConfiguration", "BackPolymorphEventFile", "backpolymorph.wav"); // BackPolymorphEventFile
        CFGDef_UseSpecialSoundsFromPStruct = cfgdefs->ReadBool("PRMConfiguration", "UseSpecialSoundsFromPStruct", true); // UseSpecialSoundsFromPStruct
        CFGDef_UseMusic                    = cfgdefs->ReadBool("PRMConfiguration", "UseMusic", true); // UseMusic
        CFGDef_Volume                      = cfgdefs->ReadInteger("PRMConfiguration", "Volume", 50); // Volume
        CFGDef_PlayInHiddenMode            = cfgdefs->ReadBool("PRMConfiguration", "PlayInHiddenMode", true); // PlayInHiddenMode
        CFGDef_HMVolume                    = cfgdefs->ReadInteger("PRMConfiguration", "HMVolume", 35); // HMVolume
        CFGDef_PlaySpecialFiles            = cfgdefs->ReadBool("PRMConfiguration", "PlaySpecialFiles", true); // PlaySpecialFiles
        CFGDef_PSShowFullStatistics        = cfgdefs->ReadBool("PRMConfiguration", "PSShowFullStatistics", true); // PSShowFullStatistics
        CFGDef_PSClaShowFullStatistics     = cfgdefs->ReadBool("PRMConfiguration", "PSClaShowFullStatistics", true); // PSClaShowFullStatistics
        CFGDef_PSAShowFullStatistics       = cfgdefs->ReadBool("PRMConfiguration", "PSAShowFullStatistics", true); // PSAShowFullStatistics
        CFGDef_PSCluShowFullStatistics     = cfgdefs->ReadBool("PRMConfiguration", "PSCluShowFullStatistics", true); // PSCluShowFullStatistics
        CFGDef_PSFShowFullStatistics       = cfgdefs->ReadBool("PRMConfiguration", "PSFShowFullStatistics", true); // PSFShowFullStatistics
        CFGDef_UseProtection               = cfgdefs->ReadBool("PRMConfiguration", "UseProtection", false); // UseProtection
        CFGDef_CheckForUpdates             = cfgdefs->ReadBool("PRMConfiguration", "CheckForUpdates", true); // CheckForUpdates
        CFGDef_CheckForUpdatesPStruct      = cfgdefs->ReadBool("PRMConfiguration", "CheckForUpdatesPStruct", true); // CheckForUpdatesPStruct
        CFGDef_CheckForUpdatesRoute        = cfgdefs->ReadBool("PRMConfiguration", "CheckForUpdatesRoute", true); // CheckForUpdatesRoute
        CFGDef_AutoCheckWhenPRMStarts      = cfgdefs->ReadBool("PRMConfiguration", "AutoCheckWhenPRMStarts", true); // AutoCheckWhenPRMStarts
        CFGDef_DownloadAutomatically       = cfgdefs->ReadBool("PRMConfiguration", "DownloadAutomatically", true); // DownloadAutomatically
        CFGDef_ShowProgressWindow          = cfgdefs->ReadBool("PRMConfiguration", "ShowProgressWindow", true); // ShowProgressWindow
        delete cfgdefs;
        // Initialization 3, File: guicfg.ini (GUI configuration filelist)
        TIniFile *guicfg;
        guicfg = new TIniFile(GlPRMPath + CFG_PRM1GUICfgMainFile);
        // [FileNames]
        GUIF_cfgMainWindow              = GlPRMCFGPath + guicfg->ReadString("FileNames", "cfgMainWindow", "mw") + ".ini"; // cfgMainWindow
        GUIF_cfgAboutWindow             = GlPRMCFGPath + guicfg->ReadString("FileNames", "cfgAboutWindow", "aw") + ".ini"; // cfgAboutWindow
        GUIF_cfgRouteStatsWindow        = GlPRMCFGPath + guicfg->ReadString("FileNames", "cfgRouteStatsWindow", "rstatsw") + ".ini"; // cfgRouteStatsWindow
        GUIF_cfgPStructStatsWindow      = GlPRMCFGPath + guicfg->ReadString("FileNames", "cfgPStructStatsWindow", "pstructstatsw") + ".ini"; // cfgPStructStatsWindow
        GUIF_cfgReportWindow            = GlPRMCFGPath + guicfg->ReadString("FileNames", "cfgReportWindow", "repw") + ".ini"; // cfgReportWindow
        GUIF_cfgConfigurationWindow     = GlPRMCFGPath + guicfg->ReadString("FileNames", "cfgConfigurationWindow", "cfgw") + ".ini"; // cfgConfigurationWindow
        delete cfgdefs;
        // Initialization 4, File: mw.ini (GUI configuration of Main window)
        TIniFile *mw;
        mw = new TIniFile(GUIF_cfgMainWindow);
        // [MainWindow]
        if(mw->ReadInteger("MainWindow", "Position", 3)!=5 || mw->ReadInteger("MainWindow", "Position", 3)!=6)
        {
                cfgMW_Position = mw->ReadInteger("MainWindow", "Position", 3); // Position
        }
        cfgMW_Left              = mw->ReadInteger("MainWindow", "Left", 192); // Left
        cfgMW_Top               = mw->ReadInteger("MainWindow", "Top", 109); // Top
        cfgMW_Height            = mw->ReadInteger("MainWindow", "Height", 419); // Height
        cfgMW_Width             = mw->ReadInteger("MainWindow", "Width", 528); // Width
        cfgMW_biMinimize        = mw->ReadBool("MainWindow", "biMinimize", true); // biMinimize
        cfgMW_Color             = mw->ReadString("MainWindow", "Color", "$09000015"); // Color
        cfgMW_CursorType        = mw->ReadInteger("MainWindow", "CursorType", 0); // CursorType
        if(cfgMW_CursorType==22)
        {
                if(mw->ReadString("MainWindow", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMW_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMW_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMW_UserCursorFile = GlPRMCursorsPath + mw->ReadString("MainWindow", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgMW_FontColor         = mw->ReadString("MainWindow", "FontColor", "000000"); // FontColor
        cfgMW_FontName          = mw->ReadString("MainWindow", "FontName", "Arial"); // FontName
        cfgMW_FontSize          = mw->ReadInteger("MainWindow", "FontSize", 8); // FontSize
        cfgMW_fsBold            = mw->ReadBool("MainWindow", "fsBold", false); // fsBold
        cfgMW_fsItalic          = mw->ReadBool("MainWindow", "fsItalic", false); // fsItalic
        cfgMW_fsUnderline       = mw->ReadBool("MainWindow", "fsUnderline", false); // fsUnderline
        cfgMW_fsStrikeOut       = mw->ReadBool("MainWindow", "fsStrikeOut", false); // fsStrikeOut
        cfgMW_FormStyle         = mw->ReadString("MainWindow", "FormStyle", "Normal"); // FormStyle
        if(mw->ReadString("MainWindow", "Icon", "")!="")
        {
                if(FileExist(GlPRMIconsPath + mw->ReadString("MainWindow", "Icon", "")))
                {
                        cfgMW_Icon = GlPRMIconsPath + mw->ReadString("MainWindow", "Icon", ""); // Icon
                }
        }
        // [MWBackgroundImage]
        if(mw->ReadString("MWBackgroundImage", "ImageFile", "")!="")
        {
                if(FileExist(GlPRMImgPath + mw->ReadString("MWBackgroundImage", "ImageFile", "")))
                {
                        cfgMWBI_ImageFile = GlPRMImgPath + mw->ReadString("MainWindow", "ImageFile", ""); // ImageFile
                }
        }
        cfgMWBI_Stretch         = mw->ReadBool("MWBackgroundImage", "Stretch", true); // Stretch
        cfgMWBI_Center          = mw->ReadBool("MWBackgroundImage", "Center", false); // Center
        cfgMWBI_Transparent     = mw->ReadBool("MWBackgroundImage", "Transparent", false); // Transparent
        // [MWClocks]
        cfgMWClocks_ClockHMSSeparator   = mw->ReadString("MWClocks", "ClockHMSSeparator", ":"); // ClockHMSSeparator
        cfgMWClocks_ClockHMSeparator    = mw->ReadString("MWClocks", "ClockHMSeparator", ":"); // ClockHMSeparator
        cfgMWClocks_LMinuteSeparator    = mw->ReadString("MWClocks", "LMinuteSeparator", ":"); // LMinuteSeparator
        cfgMWClocks_ClockHMSLeft        = mw->ReadInteger("MWClocks", "ClockHMSLeft", 468); // ClockHMSLeft
        cfgMWClocks_ClockHMLeft         = mw->ReadInteger("MWClocks", "ClockHMLeft", 485); // ClockHMLeft
        cfgMWClocks_LHourLeft           = mw->ReadInteger("MWClocks", "LHourLeft", 463); // LHourLeft
        cfgMWClocks_LMinuteLeft         = mw->ReadInteger("MWClocks", "LMinuteLeft", 492); // LMinuteLeft
        cfgMWClocks_LAMPMLeft           = mw->ReadInteger("MWClocks", "LAMPMLeft", 492); // LAMPMLeft
        cfgMWClocks_LDayLeft            = mw->ReadInteger("MWClocks", "LDayLeft", 492); // LDayLeft
        cfgMWClocks_ClockHMSTop         = mw->ReadInteger("MWClocks", "ClockHMSTop", 4); // ClockHMSTop
        cfgMWClocks_ClockHMTop          = mw->ReadInteger("MWClocks", "ClockHMTop", 4); // ClockHMTop
        cfgMWClocks_LHourTop            = mw->ReadInteger("MWClocks", "LHourTop", 3); // LHourTop
        cfgMWClocks_LMinuteTop          = mw->ReadInteger("MWClocks", "LMinuteTop", 5); // LMinuteTop
        cfgMWClocks_LAMPMTop            = mw->ReadInteger("MWClocks", "LAMPMTop", 13); // LAMPMTop
        cfgMWClocks_LDayTop             = mw->ReadInteger("MWClocks", "LDayTop", 13); // LDayTop
        cfgMWClocks_ClockHMSFColor      = mw->ReadString("MWClocks", "ClockHMSFColor", "$09000008"); // ClockHMSFColor
        cfgMWClocks_ClockHMFColor       = mw->ReadString("MWClocks", "ClockHMFColor", "$09000008"); // ClockHMFColor
        cfgMWClocks_LHourFColor         = mw->ReadString("MWClocks", "LHourFColor", "$09000008"); // LHourFColor
        cfgMWClocks_LMinuteFColor       = mw->ReadString("MWClocks", "LMinuteFColor", "$09000008"); // LMinuteFColor
        cfgMWClocks_LAMPMFColor         = mw->ReadString("MWClocks", "LAMPMFColor", "$09000008"); // LAMPMFColor
        cfgMWClocks_LDayFColor          = mw->ReadString("MWClocks", "LDayFColor", "$09000008"); // LDayFColor
        cfgMWClocks_ClockHMSFName       = mw->ReadString("MWClocks", "ClockHMSFName", "Arial"); // ClockHMSFName
        cfgMWClocks_ClockHMFName        = mw->ReadString("MWClocks", "ClockHMFName", "Arial"); // ClockHMFName
        cfgMWClocks_LHourFName          = mw->ReadString("MWClocks", "LHourFName", "Arial"); // LHourFName
        cfgMWClocks_LMinuteFName        = mw->ReadString("MWClocks", "LMinuteFName", "Arial"); // LMinuteFName
        cfgMWClocks_LAMPMFName          = mw->ReadString("MWClocks", "LAMPMFName", "Arial"); // LAMPMFName
        cfgMWClocks_LDayFName           = mw->ReadString("MWClocks", "LDayFName", "Arial"); // LDayFName
        cfgMWClocks_ClockHMSFSize       = mw->ReadInteger("MWClocks", "ClockHMSFSize", 9); // ClockHMSFSize
        cfgMWClocks_ClockHMFSize        = mw->ReadInteger("MWClocks", "ClockHMFSize", 9); // ClockHMFSize
        cfgMWClocks_LHourFSize          = mw->ReadInteger("MWClocks", "LHourFSize", 18); // LHourFSize
        cfgMWClocks_LMinuteFSize        = mw->ReadInteger("MWClocks", "LMinuteFSize", 8); // LMinuteFSize
        cfgMWClocks_LAMPMFSize          = mw->ReadInteger("MWClocks", "LAMPMFSize", 8); // LAMPMFSize
        cfgMWClocks_LDayFSize           = mw->ReadInteger("MWClocks", "LDayFSize", 8); // LDayFSize
        cfgMWClocks_ClockHMSfsBold      = mw->ReadBool("MWClocks", "ClockHMSfsBold", true); // ClockHMSfsBold
        cfgMWClocks_ClockHMfsBold       = mw->ReadBool("MWClocks", "ClockHMfsBold", true); // ClockHMfsBold
        cfgMWClocks_LHourfsBold         = mw->ReadBool("MWClocks", "LHourfsBold", true); // LHourfsBold
        cfgMWClocks_LMinutefsBold       = mw->ReadBool("MWClocks", "LMinutefsBold", true); // LMinutefsBold
        cfgMWClocks_LAMPMfsBold         = mw->ReadBool("MWClocks", "LAMPMfsBold", true); // LAMPMfsBold
        cfgMWClocks_LDayfsBold          = mw->ReadBool("MWClocks", "LDayfsBold", true); // LDayfsBold
        cfgMWClocks_ClockHMSfsItalic    = mw->ReadBool("MWClocks", "ClockHMSfsItalic", false); // ClockHMSfsItalic
        cfgMWClocks_ClockHMfsItalic     = mw->ReadBool("MWClocks", "ClockHMfsItalic", false); // ClockHMfsItalic
        cfgMWClocks_LHourfsItalic       = mw->ReadBool("MWClocks", "LHourfsItalic", false); // LHourfsItalic
        cfgMWClocks_LMinutefsItalic     = mw->ReadBool("MWClocks", "LMinutefsItalic", false); // LMinutefsItalic
        cfgMWClocks_LAMPMfsItalic       = mw->ReadBool("MWClocks", "LAMPMfsItalic", false); // LAMPMfsItalic
        cfgMWClocks_LDayfsItalic        = mw->ReadBool("MWClocks", "LDayfsItalic", false); // LDayfsItalic
        cfgMWClocks_ClockHMSfsUnderline = mw->ReadBool("MWClocks", "ClockHMSfsUnderline", false); // ClockHMSfsUnderline
        cfgMWClocks_ClockHMfsUnderline  = mw->ReadBool("MWClocks", "ClockHMfsUnderline", false); // ClockHMfsUnderline
        cfgMWClocks_LHourfsUnderline    = mw->ReadBool("MWClocks", "LHourfsUnderline", false); // LHourfsUnderline
        cfgMWClocks_LMinutefsUnderline  = mw->ReadBool("MWClocks", "LMinutefsUnderline", false); // LMinutefsUnderline
        cfgMWClocks_LAMPMfsUnderline    = mw->ReadBool("MWClocks", "LAMPMfsUnderline", false); // LAMPMfsUnderline
        cfgMWClocks_LDayfsUnderline     = mw->ReadBool("MWClocks", "LDayfsUnderline", false); // LDayfsUnderline
        cfgMWClocks_ClockHMSfsStrikeOut = mw->ReadBool("MWClocks", "ClockHMSfsStrikeOut", false); // ClockHMSfsStrikeOut
        cfgMWClocks_ClockHMfsStrikeOut  = mw->ReadBool("MWClocks", "ClockHMfsStrikeOut", false); // ClockHMfsStrikeOut
        cfgMWClocks_LHourfsStrikeOut    = mw->ReadBool("MWClocks", "LHourfsStrikeOut", false); // LHourfsStrikeOut
        cfgMWClocks_LMinutefsStrikeOut  = mw->ReadBool("MWClocks", "LMinutefsStrikeOut", false); // LMinutefsStrikeOut
        cfgMWClocks_LAMPMfsStrikeOut    = mw->ReadBool("MWClocks", "LAMPMfsStrikeOut", false); // LAMPMfsStrikeOut
        cfgMWClocks_LDayfsStrikeOut     = mw->ReadBool("MWClocks", "LDayfsStrikeOut", false); // LDayfsStrikeOut
        cfgMWClocks_ClockHMSAlignment   = mw->ReadInteger("MWClocks", "ClockHMSAlignment", 2); // ClockHMSAlignment
        cfgMWClocks_ClockHMAlignment    = mw->ReadInteger("MWClocks", "ClockHMAlignment", 2); // ClockHMAlignment
        cfgMWClocks_LHourAlignment      = mw->ReadInteger("MWClocks", "LHourAlignment", 2); // LHourAlignment
        cfgMWClocks_LMinuteAlignment    = mw->ReadInteger("MWClocks", "LMinuteAlignment", 0); // LMinuteAlignment
        cfgMWClocks_LAMPMAlignment      = mw->ReadInteger("MWClocks", "LAMPMAlignment", 0); // LAMPMAlignment
        cfgMWClocks_LDayAlignment       = mw->ReadInteger("MWClocks", "LDayAlignment", 0); // LDayAlignment
        cfgMWClocks_ClockHMSLayout      = mw->ReadInteger("MWClocks", "ClockHMSLayout", 0); // ClockHMSLayout
        cfgMWClocks_ClockHMLayout       = mw->ReadInteger("MWClocks", "ClockHMLayout", 0); // ClockHMLayout
        cfgMWClocks_LHourLayout         = mw->ReadInteger("MWClocks", "LHourLayout", 0); // LHourLayout
        cfgMWClocks_LMinuteLayout       = mw->ReadInteger("MWClocks", "LMinuteLayout", 0); // LMinuteLayout
        cfgMWClocks_LAMPMLayout         = mw->ReadInteger("MWClocks", "LAMPMLayout", 0); // LAMPMLayout
        cfgMWClocks_LDayLayout          = mw->ReadInteger("MWClocks", "LDayLayout", 0); // LDayLayout
        cfgMWClocks_ClockHMSHint        = mw->ReadString("MWClocks", "ClockHMSHint", "$date$"); // ClockHMSHint
        cfgMWClocks_ClockHMHint         = mw->ReadString("MWClocks", "ClockHMHint", "$date$"); // ClockHMHint
        cfgMWClocks_LHourHint           = mw->ReadString("MWClocks", "LHourHint", "$date$"); // LHourHint
        cfgMWClocks_LMinuteHint         = mw->ReadString("MWClocks", "LMinuteHint", "$date$"); // LMinuteHint
        cfgMWClocks_LAMPMHint           = mw->ReadString("MWClocks", "LAMPMHint", "$date$"); // LAMPMHint
        cfgMWClocks_LDayHint            = mw->ReadString("MWClocks", "LDayHint", "$date$"); // LDayHint
        cfgMWClocks_TypeOfDateForHint   = mw->ReadInteger("MWClocks", "TypeOfDateForHint", 1); // TypeOfDateForHint
        cfgMWClocks_ClockHMSTransparent = mw->ReadBool("MWClocks", "ClockHMSTransparent", true); // ClockHMSTransparent
        cfgMWClocks_ClockHMSBackColor   = mw->ReadString("MWClocks", "ClockHMSBackColor", "FFFFFF"); // ClockHMSBackColor
        cfgMWClocks_ClockHMSCursorType  = mw->ReadInteger("MWClocks", "ClockHMSCursorType", 0); // ClockHMSCursorType
        if(cfgMWClocks_ClockHMSCursorType==22)
        {
                if(mw->ReadString("MWClocks", "cfgMWClocks_ClockHMSUserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWClocks_ClockHMSUserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWClocks_ClockHMSCursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWClocks_ClockHMSUserCursorFile = GlPRMCursorsPath + mw->ReadString("MWClocks", "ClockHMSUserCursorFile", "std.cur"); // ClockHMSUserCursorFile
                }
        }
        cfgMWClocks_ClockHMCursorType = mw->ReadInteger("MWClocks", "ClockHMCursorType", 0); // ClockHMCursorType
        if(cfgMWClocks_ClockHMCursorType==22)
        {
                if(mw->ReadString("MWClocks", "ClockHMUserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWClocks_ClockHMUserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWClocks_ClockHMCursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWClocks_ClockHMUserCursorFile = GlPRMCursorsPath + mw->ReadString("MWClocks", "ClockHMUserCursorFile", "std.cur"); // ClockHMUserCursorFile
                }
        }
        cfgMWClocks_LHourCursorType = mw->ReadInteger("MWClocks", "LHourCursorType", 0); // LHourCursorType
        if(cfgMWClocks_LHourCursorType==22)
        {
                if(mw->ReadString("MWClocks", "LHourUserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWClocks_LHourUserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWClocks_LHourCursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWClocks_LHourUserCursorFile = GlPRMCursorsPath + mw->ReadString("MWClocks", "LHourUserCursorFile", "std.cur"); // LHourUserCursorFile
                }
        }
        cfgMWClocks_LMinuteCursorType = mw->ReadInteger("MWClocks", "LMinuteCursorType", 0); // LMinuteCursorType
        if(cfgMWClocks_LMinuteCursorType==22)
        {
                if(mw->ReadString("MWClocks", "LMinuteUserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWClocks_LMinuteUserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWClocks_LMinuteCursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWClocks_LMinuteUserCursorFile = GlPRMCursorsPath + mw->ReadString("MWClocks", "LMinuteUserCursorFile", "std.cur"); // LMinuteUserCursorFile
                }
        }
        cfgMWClocks_LAMPMCursorType = mw->ReadInteger("MWClocks", "LAMPMCursorType", 0); // LAMPMCursorType
        if(cfgMWClocks_LAMPMCursorType==22)
        {
                if(mw->ReadString("MWClocks", "LAMPMUserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWClocks_LAMPMUserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWClocks_LAMPMCursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWClocks_LAMPMUserCursorFile = GlPRMCursorsPath + mw->ReadString("MWClocks", "LAMPMUserCursorFile", "std.cur"); // LAMPMUserCursorFile
                }
        }
        cfgMWClocks_LDayCursorType = mw->ReadInteger("MWClocks", "LDayCursorType", 0); // LDayCursorType
        if(cfgMWClocks_LDayCursorType==22)
        {
                if(mw->ReadString("MWClocks", "LDayUserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWClocks_LDayUserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWClocks_LDayCursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWClocks_LDayUserCursorFile = GlPRMCursorsPath + mw->ReadString("MWClocks", "LDayUserCursorFile", "std.cur"); // LDayUserCursorFile
                }
        }
        // [MWHiddenWorkButton]
        cfgMWHWB_Visible        = mw->ReadBool("MWHiddenWorkButton", "Visible", true); // Visible
        cfgMWHWB_Enabled        = mw->ReadBool("MWHiddenWorkButton", "Enabled", true); // Enabled
        cfgMWHWB_Left           = mw->ReadInteger("MWHiddenWorkButton", "Left", 8); // Left
        cfgMWHWB_Top            = mw->ReadInteger("MWHiddenWorkButton", "Top", 360); // Top
        cfgMWHWB_Height         = mw->ReadInteger("MWHiddenWorkButton", "Height", 22); // Height
        cfgMWHWB_Width          = mw->ReadInteger("MWHiddenWorkButton", "Width", 73); // Width
        cfgMWHWB_CursorType     = mw->ReadInteger("MWHiddenWorkButton", "CursorType", 20); // CursorType
        if(cfgMWHWB_CursorType==22)
        {
                if(mw->ReadString("MWHiddenWorkButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWHWB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWHWB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWHWB_UserCursorFile = GlPRMCursorsPath + mw->ReadString("MWHiddenWorkButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgMWHWB_Flat           = mw->ReadBool("MWHiddenWorkButton", "Flat", false); // Flat
        cfgMWHWB_FontColor      = mw->ReadString("MWHiddenWorkButton", "FontColor", "$09000008"); // FontColor
        cfgMWHWB_FontName       = mw->ReadString("MWHiddenWorkButton", "FontName", "Arial"); // FontName
        cfgMWHWB_FontSize       = mw->ReadInteger("MWHiddenWorkButton", "FontSize", 8); // FontSize
        cfgMWHWB_fsBold         = mw->ReadBool("MWHiddenWorkButton", "fsBold", false); // fsBold
        cfgMWHWB_fsItalic       = mw->ReadBool("MWHiddenWorkButton", "fsItalic", false); // fsItalic
        cfgMWHWB_fsUnderline    = mw->ReadBool("MWHiddenWorkButton", "fsUnderline", false); // fsUnderline
        cfgMWHWB_fsStrikeOut    = mw->ReadBool("MWHiddenWorkButton", "fsStrikeOut", false); // fsStrikeOut
        if(mw->ReadString("MWHiddenWorkButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + mw->ReadString("MWHiddenWorkButton", "Glyph", "")))
                {
                        cfgMWHWB_Glyph = GlPRMImgBtnPath + mw->ReadString("MWHiddenWorkButton", "Glyph", ""); // Glyph
                }
        }
        cfgMWHWB_Hint           = mw->ReadString("MWHiddenWorkButton", "Hint", ""); // Hint
        cfgMWHWB_Layout         = mw->ReadInteger("MWHiddenWorkButton", "Layout", 0); // Layout
        cfgMWHWB_Margin         = mw->ReadString("MWHiddenWorkButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgMWHWB_Spacing        = mw->ReadInteger("MWHiddenWorkButton", "Spacing", 4); // Spacing
        // [MWConfigurationButton]
        cfgMWCB_Visible         = mw->ReadBool("MWConfigurationButton", "Visible", true); // Visible
        cfgMWCB_Enabled         = mw->ReadBool("MWConfigurationButton", "Enabled", true); // Enabled
        cfgMWCB_Left            = mw->ReadInteger("MWConfigurationButton", "Left", 88); // Left
        cfgMWCB_Top             = mw->ReadInteger("MWConfigurationButton", "Top", 360); // Top
        cfgMWCB_Height          = mw->ReadInteger("MWConfigurationButton", "Height", 22); // Height
        cfgMWCB_Width           = mw->ReadInteger("MWConfigurationButton", "Width", 73); // Width
        cfgMWCB_CursorType      = mw->ReadInteger("MWConfigurationButton", "CursorType", 20); // CursorType
        if(cfgMWCB_CursorType==22)
        {
                if(mw->ReadString("MWConfigurationButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWCB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWCB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWCB_UserCursorFile = GlPRMCursorsPath + mw->ReadString("MWConfigurationButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgMWCB_Flat            = mw->ReadBool("MWConfigurationButton", "Flat", false); // Flat
        cfgMWCB_FontColor       = mw->ReadString("MWConfigurationButton", "FontColor", "$09000008"); // FontColor
        cfgMWCB_FontName        = mw->ReadString("MWConfigurationButton", "FontName", "Arial"); // FontName
        cfgMWCB_FontSize        = mw->ReadInteger("MWConfigurationButton", "FontSize", 8); // FontSize
        cfgMWCB_fsBold          = mw->ReadBool("MWConfigurationButton", "fsBold", false); // fsBold
        cfgMWCB_fsItalic        = mw->ReadBool("MWConfigurationButton", "fsItalic", false); // fsItalic
        cfgMWCB_fsUnderline     = mw->ReadBool("MWConfigurationButton", "fsUnderline", false); // fsUnderline
        cfgMWCB_fsStrikeOut     = mw->ReadBool("MWConfigurationButton", "fsStrikeOut", false); // fsStrikeOut
        if(mw->ReadString("MWConfigurationButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + mw->ReadString("MWConfigurationButton", "Glyph", "")))
                {
                        cfgMWCB_Glyph = GlPRMImgBtnPath + mw->ReadString("MWConfigurationButton", "Glyph", ""); // Glyph
                }
        }
        cfgMWCB_Hint            = mw->ReadString("MWConfigurationButton", "Hint", ""); // Hint
        cfgMWCB_Layout          = mw->ReadInteger("MWConfigurationButton", "Layout", 0); // Layout
        cfgMWCB_Margin          = mw->ReadString("MWConfigurationButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgMWCB_Spacing         = mw->ReadInteger("MWConfigurationButton", "Spacing", 4); // Spacing
        // [MWReportButton]
        cfgMWRB_Visible         = mw->ReadBool("MWReportButton", "Visible", true); // Visible
        cfgMWRB_Enabled         = mw->ReadBool("MWReportButton", "Enabled", true); // Enabled
        cfgMWRB_Left            = mw->ReadInteger("MWReportButton", "Left", 168); // Left
        cfgMWRB_Top             = mw->ReadInteger("MWReportButton", "Top", 360); // Top
        cfgMWRB_Height          = mw->ReadInteger("MWReportButton", "Height", 22); // Height
        cfgMWRB_Width           = mw->ReadInteger("MWReportButton", "Width", 49); // Width
        cfgMWRB_CursorType      = mw->ReadInteger("MWReportButton", "CursorType", 20); // CursorType
        if(cfgMWRB_CursorType==22)
        {
                if(mw->ReadString("MWReportButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWRB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWRB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWRB_UserCursorFile = GlPRMCursorsPath + mw->ReadString("MWReportButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgMWRB_Flat            = mw->ReadBool("MWReportButton", "Flat", false); // Flat
        cfgMWRB_FontColor       = mw->ReadString("MWReportButton", "FontColor", "$09000008"); // FontColor
        cfgMWRB_FontName        = mw->ReadString("MWReportButton", "FontName", "Arial"); // FontName
        cfgMWRB_FontSize        = mw->ReadInteger("MWReportButton", "FontSize", 8); // FontSize
        cfgMWRB_fsBold          = mw->ReadBool("MWReportButton", "fsBold", false); // fsBold
        cfgMWRB_fsItalic        = mw->ReadBool("MWReportButton", "fsItalic", false); // fsItalic
        cfgMWRB_fsUnderline     = mw->ReadBool("MWReportButton", "fsUnderline", false); // fsUnderline
        cfgMWRB_fsStrikeOut     = mw->ReadBool("MWReportButton", "fsStrikeOut", false); // fsStrikeOut
        if(mw->ReadString("MWReportButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + mw->ReadString("MWReportButton", "Glyph", "")))
                {
                        cfgMWRB_Glyph = GlPRMImgBtnPath + mw->ReadString("MWReportButton", "Glyph", ""); // Glyph
                }
        }
        cfgMWRB_Hint            = mw->ReadString("MWReportButton", "Hint", ""); // Hint
        cfgMWRB_Layout          = mw->ReadInteger("MWReportButton", "Layout", 0); // Layout
        cfgMWRB_Margin          = mw->ReadString("MWReportButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgMWRB_Spacing         = mw->ReadInteger("MWReportButton", "Spacing", 4); // Spacing
        // [MWPolymorphButton]
        cfgMWPB_Visible         = mw->ReadBool("MWPolymorphButton", "Visible", true); // Visible
        cfgMWPB_Enabled         = mw->ReadBool("MWPolymorphButton", "Enabled", true); // Enabled
        cfgMWPB_Left            = mw->ReadInteger("MWPolymorphButton", "Left", 224); // Left
        cfgMWPB_Top             = mw->ReadInteger("MWPolymorphButton", "Top", 360); // Top
        cfgMWPB_Height          = mw->ReadInteger("MWPolymorphButton", "Height", 22); // Height
        cfgMWPB_Width           = mw->ReadInteger("MWPolymorphButton", "Width", 65); // Width
        cfgMWPB_CursorType      = mw->ReadInteger("MWPolymorphButton", "CursorType", 20); // CursorType
        if(cfgMWPB_CursorType==22)
        {
                if(mw->ReadString("MWPolymorphButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWPB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWPB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWPB_UserCursorFile = GlPRMCursorsPath + mw->ReadString("MWPolymorphButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgMWPB_Flat            = mw->ReadBool("MWPolymorphButton", "Flat", false); // Flat
        cfgMWPB_FontColor       = mw->ReadString("MWPolymorphButton", "FontColor", "$09000008"); // FontColor
        cfgMWPB_FontName        = mw->ReadString("MWPolymorphButton", "FontName", "Arial"); // FontName
        cfgMWPB_FontSize        = mw->ReadInteger("MWPolymorphButton", "FontSize", 8); // FontSize
        cfgMWPB_fsBold          = mw->ReadBool("MWPolymorphButton", "fsBold", false); // fsBold
        cfgMWPB_fsItalic        = mw->ReadBool("MWPolymorphButton", "fsItalic", false); // fsItalic
        cfgMWPB_fsUnderline     = mw->ReadBool("MWPolymorphButton", "fsUnderline", false); // fsUnderline
        cfgMWPB_fsStrikeOut     = mw->ReadBool("MWPolymorphButton", "fsStrikeOut", false); // fsStrikeOut
        if(mw->ReadString("MWPolymorphButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + mw->ReadString("MWPolymorphButton", "Glyph", "")))
                {
                        cfgMWPB_Glyph = GlPRMImgBtnPath + mw->ReadString("MWPolymorphButton", "Glyph", ""); // Glyph
                }
        }
        cfgMWPB_Hint            = mw->ReadString("MWPolymorphButton", "Hint", ""); // Hint
        cfgMWPB_Layout          = mw->ReadInteger("MWPolymorphButton", "Layout", 0); // Layout
        cfgMWPB_Margin          = mw->ReadString("MWPolymorphButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgMWPB_Spacing         = mw->ReadInteger("MWPolymorphButton", "Spacing", 4); // Spacing
        // [MWAboutButton]
        cfgMWAB_Visible         = mw->ReadBool("MWAboutButton", "Visible", true); // Visible
        cfgMWAB_Enabled         = mw->ReadBool("MWAboutButton", "Enabled", true); // Enabled
        cfgMWAB_Left            = mw->ReadInteger("MWAboutButton", "Left", 296); // Left
        cfgMWAB_Top             = mw->ReadInteger("MWAboutButton", "Top", 360); // Top
        cfgMWAB_Height          = mw->ReadInteger("MWAboutButton", "Height", 22); // Height
        cfgMWAB_Width           = mw->ReadInteger("MWAboutButton", "Width", 49); // Width
        cfgMWAB_CursorType      = mw->ReadInteger("MWAboutButton", "CursorType", 20); // CursorType
        if(cfgMWAB_CursorType==22)
        {
                if(mw->ReadString("MWAboutButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWAB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWAB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWAB_UserCursorFile = GlPRMCursorsPath + mw->ReadString("MWAboutButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgMWAB_Flat            = mw->ReadBool("MWAboutButton", "Flat", false); // Flat
        cfgMWAB_FontColor       = mw->ReadString("MWAboutButton", "FontColor", "$09000008"); // FontColor
        cfgMWAB_FontName        = mw->ReadString("MWAboutButton", "FontName", "Arial"); // FontName
        cfgMWAB_FontSize        = mw->ReadInteger("MWAboutButton", "FontSize", 8); // FontSize
        cfgMWAB_fsBold          = mw->ReadBool("MWAboutButton", "fsBold", false); // fsBold
        cfgMWAB_fsItalic        = mw->ReadBool("MWAboutButton", "fsItalic", false); // fsItalic
        cfgMWAB_fsUnderline     = mw->ReadBool("MWAboutButton", "fsUnderline", false); // fsUnderline
        cfgMWAB_fsStrikeOut     = mw->ReadBool("MWAboutButton", "fsStrikeOut", false); // fsStrikeOut
        if(mw->ReadString("MWAboutButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + mw->ReadString("MWAboutButton", "Glyph", "")))
                {
                        cfgMWAB_Glyph = GlPRMImgBtnPath + mw->ReadString("MWAboutButton", "Glyph", ""); // Glyph
                }
        }
        cfgMWAB_Hint            = mw->ReadString("MWAboutButton", "Hint", ""); // Hint
        cfgMWAB_Layout          = mw->ReadInteger("MWAboutButton", "Layout", 0); // Layout
        cfgMWAB_Margin          = mw->ReadString("MWAboutButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgMWAB_Spacing         = mw->ReadInteger("MWAboutButton", "Spacing", 4); // Spacing
        // [MWExitButton]
        cfgMWEB_Visible         = mw->ReadBool("MWExitButton", "Visible", true); // Visible
        cfgMWEB_Enabled         = mw->ReadBool("MWExitButton", "Enabled", true); // Enabled
        cfgMWEB_Left            = mw->ReadInteger("MWExitButton", "Left", 296); // Left
        cfgMWEB_Top             = mw->ReadInteger("MWExitButton", "Top", 360); // Top
        cfgMWEB_Height          = mw->ReadInteger("MWExitButton", "Height", 22); // Height
        cfgMWEB_Width           = mw->ReadInteger("MWExitButton", "Width", 49); // Width
        cfgMWEB_CursorType      = mw->ReadInteger("MWExitButton", "CursorType", 20); // CursorType
        if(cfgMWEB_CursorType==22)
        {
                if(mw->ReadString("MWExitButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgMWEB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgMWEB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgMWEB_UserCursorFile = GlPRMCursorsPath + mw->ReadString("MWExitButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgMWEB_Flat            = mw->ReadBool("MWExitButton", "Flat", false); // Flat
        cfgMWEB_FontColor       = mw->ReadString("MWExitButton", "FontColor", "$09000008"); // FontColor
        cfgMWEB_FontName        = mw->ReadString("MWExitButton", "FontName", "Arial"); // FontName
        cfgMWEB_FontSize        = mw->ReadInteger("MWExitButton", "FontSize", 8); // FontSize
        cfgMWEB_fsBold          = mw->ReadBool("MWExitButton", "fsBold", false); // fsBold
        cfgMWEB_fsItalic        = mw->ReadBool("MWExitButton", "fsItalic", false); // fsItalic
        cfgMWEB_fsUnderline     = mw->ReadBool("MWExitButton", "fsUnderline", false); // fsUnderline
        cfgMWEB_fsStrikeOut     = mw->ReadBool("MWExitButton", "fsStrikeOut", false); // fsStrikeOut
        if(mw->ReadString("MWExitButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + mw->ReadString("MWExitButton", "Glyph", "")))
                {
                        cfgMWEB_Glyph = GlPRMImgBtnPath + mw->ReadString("MWExitButton", "Glyph", ""); // Glyph
                }
        }
        cfgMWEB_Hint            = mw->ReadString("MWExitButton", "Hint", ""); // Hint
        cfgMWEB_Layout          = mw->ReadInteger("MWExitButton", "Layout", 0); // Layout
        cfgMWEB_Margin          = mw->ReadString("MWExitButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgMWEB_Spacing         = mw->ReadInteger("MWExitButton", "Spacing", 4); // Spacing
        delete mw;
        // Initialization 5, File: aw.ini (GUI cofiguration of About window)
        TIniFile *aw;
        aw = new TIniFile(GUIF_cfgAboutWindow);
        // [AboutWindow]
        cfgAW_Position          = aw->ReadInteger("AboutWindow", "Position", 5); // Position
        cfgAW_Left              = aw->ReadInteger("AboutWindow", "Left", 192); // Left
        cfgAW_Top               = aw->ReadInteger("AboutWindow", "Top", 109); // Top
        cfgAW_Height            = aw->ReadInteger("AboutWindow", "Height", 349); // Height
        cfgAW_Width             = aw->ReadInteger("AboutWindow", "Width", 508); // Width
        cfgAW_biMinimize        = aw->ReadBool("AboutWindow", "biMinimize", true); // biMinimize
        cfgAW_Color             = aw->ReadString("AboutWindow", "Color", "$09000015"); // Color
        cfgAW_CursorType        = aw->ReadInteger("AboutWindow", "CursorType", 0); // CursorType
        if(cfgAW_CursorType==22)
        {
                if(aw->ReadString("AboutWindow", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgAW_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgAW_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgAW_UserCursorFile = GlPRMCursorsPath + aw->ReadString("AboutWindow", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgAW_FontColor         = aw->ReadString("AboutWindow", "FontColor", "$09000008"); // FontColor
        cfgAW_FontName          = aw->ReadString("AboutWindow", "FontName", "Arial"); // FontName
        cfgAW_FontSize          = aw->ReadInteger("AboutWindow", "FontSize", 8); // FontSize
        cfgAW_fsBold            = aw->ReadBool("AboutWindow", "fsBold", false); // fsBold
        cfgAW_fsItalic          = aw->ReadBool("AboutWindow", "fsItalic", false); // fsItalic
        cfgAW_fsUnderline       = aw->ReadBool("AboutWindow", "fsUnderline", false); // fsUnderline
        cfgAW_fsStrikeOut       = aw->ReadBool("AboutWindow", "fsStrikeOut", false); // fsStrikeOut
        cfgAW_FormStyle         = aw->ReadString("AboutWindow", "FormStyle", "Normal"); // FormStyle
        if(aw->ReadString("AboutWindow", "Icon", "")!="")
        {
                if(FileExist(GlPRMIconsPath + aw->ReadString("AboutWindow", "Icon", "")))
                {
                        cfgAW_Icon = GlPRMIconsPath + aw->ReadString("AboutWindow", "Icon", ""); // Icon
                }
        }
        // [AWBackgroundImage]
        if(aw->ReadString("AWBackgroundImage", "ImageFile", "")!="")
        {
                if(FileExist(GlPRMImgPath + aw->ReadString("AWBackgroundImage", "ImageFile", "")))
                {
                        cfgAWBI_ImageFile = GlPRMImgPath + aw->ReadString("MainWindow", "ImageFile", ""); // ImageFile
                }
        }
        cfgAWBI_Stretch         = aw->ReadBool("AWBackgroundImage", "Stretch", true); // Stretch
        cfgAWBI_Center          = aw->ReadBool("AWBackgroundImage", "Center", false); // Center
        cfgAWBI_Transparent     = aw->ReadBool("AWBackgroundImage", "Transparent", false); // Transparent
        // [AWOKButton]
        cfgAWOKB_Visible        = aw->ReadBool("AWOKButton", "Visible", true); // Visible
        cfgAWOKB_Enabled        = aw->ReadBool("AWOKButton", "Enabled", true); // Enabled
        cfgAWOKB_Left           = aw->ReadInteger("AWOKButton", "Left", 8); // Left
        cfgAWOKB_Top            = aw->ReadInteger("AWOKButton", "Top", 288); // Top
        cfgAWOKB_Height         = aw->ReadInteger("AWOKButton", "Height", 22); // Height
        cfgAWOKB_Width          = aw->ReadInteger("AWOKButton", "Width", 57); // Width
        cfgAWOKB_CursorType     = aw->ReadInteger("AWOKButton", "CursorType", 20); // CursorType
        if(cfgAWOKB_CursorType==22)
        {
                if(aw->ReadString("AWOKButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgAWOKB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgAWOKB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgAWOKB_UserCursorFile = GlPRMCursorsPath + aw->ReadString("AWOKButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgAWOKB_Flat           = aw->ReadBool("AWOKButton", "Flat", false); // Flat
        cfgAWOKB_FontColor      = aw->ReadString("AWOKButton", "FontColor", "$09000008"); // FontColor
        cfgAWOKB_FontName       = aw->ReadString("AWOKButton", "FontName", "Arial"); // FontName
        cfgAWOKB_FontSize       = aw->ReadInteger("AWOKButton", "FontSize", 8); // FontSize
        cfgAWOKB_fsBold         = aw->ReadBool("AWOKButton", "fsBold", true); // fsBold
        cfgAWOKB_fsItalic       = aw->ReadBool("AWOKButton", "fsItalic", false); // fsItalic
        cfgAWOKB_fsUnderline    = aw->ReadBool("AWOKButton", "fsUnderline", false); // fsUnderline
        cfgAWOKB_fsStrikeOut    = aw->ReadBool("AWOKButton", "fsStrikeOut", false); // fsStrikeOut
        if(aw->ReadString("AWOKButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + aw->ReadString("AWOKButton", "Glyph", "")))
                {
                        cfgAWOKB_Glyph = GlPRMImgBtnPath + aw->ReadString("AWOKButton", "Glyph", ""); // Glyph
                }
        }
        cfgAWOKB_Hint           = aw->ReadString("AWOKButton", "Hint", ""); // Hint
        cfgAWOKB_Layout         = aw->ReadInteger("AWOKButton", "Layout", 0); // Layout
        cfgAWOKB_Margin         = aw->ReadString("AWOKButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgAWOKB_Spacing        = aw->ReadInteger("AWOKButton", "Spacing", 4); // Spacing
        // [AWRouteInfoButton]
        cfgAWRIB_Visible        = aw->ReadBool("AWRouteInfoButton", "Visible", true); // Visible
        cfgAWRIB_Enabled        = aw->ReadBool("AWRouteInfoButton", "Enabled", true); // Enabled
        cfgAWRIB_Left           = aw->ReadInteger("AWRouteInfoButton", "Left", 208); // Left
        cfgAWRIB_Top            = aw->ReadInteger("AWRouteInfoButton", "Top", 288); // Top
        cfgAWRIB_Height         = aw->ReadInteger("AWRouteInfoButton", "Height", 22); // Height
        cfgAWRIB_Width          = aw->ReadInteger("AWRouteInfoButton", "Width", 65); // Width
        cfgAWRIB_CursorType     = aw->ReadInteger("AWRouteInfoButton", "CursorType", 20); // CursorType
        if(cfgAWRIB_CursorType==22)
        {
                if(aw->ReadString("AWRouteInfoButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgAWRIB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgAWRIB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgAWRIB_UserCursorFile = GlPRMCursorsPath + aw->ReadString("AWRouteInfoButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgAWRIB_Flat           = aw->ReadBool("AWRouteInfoButton", "Flat", false); // Flat
        cfgAWRIB_FontColor      = aw->ReadString("AWRouteInfoButton", "FontColor", "$09000008"); // FontColor
        cfgAWRIB_FontName       = aw->ReadString("AWRouteInfoButton", "FontName", "Arial"); // FontName
        cfgAWRIB_FontSize       = aw->ReadInteger("AWRouteInfoButton", "FontSize", 8); // FontSize
        cfgAWRIB_fsBold         = aw->ReadBool("AWRouteInfoButton", "fsBold", false); // fsBold
        cfgAWRIB_fsItalic       = aw->ReadBool("AWRouteInfoButton", "fsItalic", false); // fsItalic
        cfgAWRIB_fsUnderline    = aw->ReadBool("AWRouteInfoButton", "fsUnderline", false); // fsUnderline
        cfgAWRIB_fsStrikeOut    = aw->ReadBool("AWRouteInfoButton", "fsStrikeOut", false); // fsStrikeOut
        if(aw->ReadString("AWRouteInfoButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + aw->ReadString("AWRouteInfoButton", "Glyph", "")))
                {
                        cfgAWRIB_Glyph = GlPRMImgBtnPath + aw->ReadString("AWRouteInfoButton", "Glyph", ""); // Glyph
                }
        }
        cfgAWRIB_Hint           = aw->ReadString("AWRouteInfoButton", "Hint", ""); // Hint
        cfgAWRIB_Layout         = aw->ReadInteger("AWRouteInfoButton", "Layout", 0); // Layout
        cfgAWRIB_Margin         = aw->ReadString("AWRouteInfoButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgAWRIB_Spacing        = aw->ReadInteger("AWRouteInfoButton", "Spacing", 4); // Spacing
        // [AWPStructInfoButton]
        cfgAWPSIB_Visible        = aw->ReadBool("AWPStructInfoButton", "Visible", true); // Visible
        cfgAWPSIB_Enabled        = aw->ReadBool("AWPStructInfoButton", "Enabled", true); // Enabled
        cfgAWPSIB_Left           = aw->ReadInteger("AWPStructInfoButton", "Left", 280); // Left
        cfgAWPSIB_Top            = aw->ReadInteger("AWPStructInfoButton", "Top", 288); // Top
        cfgAWPSIB_Height         = aw->ReadInteger("AWPStructInfoButton", "Height", 22); // Height
        cfgAWPSIB_Width          = aw->ReadInteger("AWPStructInfoButton", "Width", 145); // Width
        cfgAWPSIB_CursorType     = aw->ReadInteger("AWPStructInfoButton", "CursorType", 20); // CursorType
        if(cfgAWPSIB_CursorType==22)
        {
                if(aw->ReadString("AWPStructInfoButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgAWPSIB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgAWPSIB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgAWPSIB_UserCursorFile = GlPRMCursorsPath + aw->ReadString("AWPStructInfoButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgAWPSIB_Flat           = aw->ReadBool("AWPStructInfoButton", "Flat", false); // Flat
        cfgAWPSIB_FontColor      = aw->ReadString("AWPStructInfoButton", "FontColor", "$09000008"); // FontColor
        cfgAWPSIB_FontName       = aw->ReadString("AWPStructInfoButton", "FontName", "Arial"); // FontName
        cfgAWPSIB_FontSize       = aw->ReadInteger("AWPStructInfoButton", "FontSize", 8); // FontSize
        cfgAWPSIB_fsBold         = aw->ReadBool("AWPStructInfoButton", "fsBold", false); // fsBold
        cfgAWPSIB_fsItalic       = aw->ReadBool("AWPStructInfoButton", "fsItalic", false); // fsItalic
        cfgAWPSIB_fsUnderline    = aw->ReadBool("AWPStructInfoButton", "fsUnderline", false); // fsUnderline
        cfgAWPSIB_fsStrikeOut    = aw->ReadBool("AWPStructInfoButton", "fsStrikeOut", false); // fsStrikeOut
        if(aw->ReadString("AWPStructInfoButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + aw->ReadString("AWPStructInfoButton", "Glyph", "")))
                {
                        cfgAWPSIB_Glyph = GlPRMImgBtnPath + aw->ReadString("AWPStructInfoButton", "Glyph", ""); // Glyph
                }
        }
        cfgAWPSIB_Hint           = aw->ReadString("AWPStructInfoButton", "Hint", ""); // Hint
        cfgAWPSIB_Layout         = aw->ReadInteger("AWPStructInfoButton", "Layout", 0); // Layout
        cfgAWPSIB_Margin         = aw->ReadString("AWPStructInfoButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgAWPSIB_Spacing        = aw->ReadInteger("AWPStructInfoButton", "Spacing", 4); // Spacing
        // [AWPRMInfoButton]
        cfgAWPRMIB_Visible        = aw->ReadBool("AWPRMInfoButton", "Visible", true); // Visible
        cfgAWPRMIB_Enabled        = aw->ReadBool("AWPRMInfoButton", "Enabled", true); // Enabled
        cfgAWPRMIB_Left           = aw->ReadInteger("AWPRMInfoButton", "Left", 432); // Left
        cfgAWPRMIB_Top            = aw->ReadInteger("AWPRMInfoButton", "Top", 288); // Top
        cfgAWPRMIB_Height         = aw->ReadInteger("AWPRMInfoButton", "Height", 22); // Height
        cfgAWPRMIB_Width          = aw->ReadInteger("AWPRMInfoButton", "Width", 57); // Width
        cfgAWPRMIB_CursorType     = aw->ReadInteger("AWPRMInfoButton", "CursorType", 20); // CursorType
        if(cfgAWPRMIB_CursorType==22)
        {
                if(aw->ReadString("AWPRMInfoButton", "UserCursorFile", "")=="")
                {
                        if(FileExist(GlPRMCursorsPath + "std.cur"))
                        {
                                cfgAWPRMIB_UserCursorFile = GlPRMCursorsPath + "std.cur";
                        }
                        else
                        {
                                cfgAWPRMIB_CursorType = 0; // Standard system cursor.
                        }
                }
                else
                {
                        cfgAWPRMIB_UserCursorFile = GlPRMCursorsPath + aw->ReadString("AWPRMInfoButton", "UserCursorFile", "std.cur"); // UserCursorFile
                }
        }
        cfgAWPRMIB_Flat           = aw->ReadBool("AWPRMInfoButton", "Flat", false); // Flat
        cfgAWPRMIB_FontColor      = aw->ReadString("AWPRMInfoButton", "FontColor", "$09000008"); // FontColor
        cfgAWPRMIB_FontName       = aw->ReadString("AWPRMInfoButton", "FontName", "Arial"); // FontName
        cfgAWPRMIB_FontSize       = aw->ReadInteger("AWPRMInfoButton", "FontSize", 8); // FontSize
        cfgAWPRMIB_fsBold         = aw->ReadBool("AWPRMInfoButton", "fsBold", false); // fsBold
        cfgAWPRMIB_fsItalic       = aw->ReadBool("AWPRMInfoButton", "fsItalic", false); // fsItalic
        cfgAWPRMIB_fsUnderline    = aw->ReadBool("AWPRMInfoButton", "fsUnderline", false); // fsUnderline
        cfgAWPRMIB_fsStrikeOut    = aw->ReadBool("AWPRMInfoButton", "fsStrikeOut", false); // fsStrikeOut
        if(aw->ReadString("AWPRMInfoButton", "Glyph", "")!="")
        {
                if(FileExist(GlPRMImgBtnPath + aw->ReadString("AWPRMInfoButton", "Glyph", "")))
                {
                        cfgAWPRMIB_Glyph = GlPRMImgBtnPath + aw->ReadString("AWPRMInfoButton", "Glyph", ""); // Glyph
                }
        }
        cfgAWPRMIB_Hint           = aw->ReadString("AWPRMInfoButton", "Hint", ""); // Hint
        cfgAWPRMIB_Layout         = aw->ReadInteger("AWPRMInfoButton", "Layout", 0); // Layout
        cfgAWPRMIB_Margin         = aw->ReadString("AWPRMInfoButton", "Margin", "-1"); // Margin, must be converted into needed type (get type from the property of component)
        cfgAWPRMIB_Spacing        = aw->ReadInteger("AWPRMInfoButton", "Spacing", 4); // Spacing
        // [AWNotebook]
        cfgAWN_Visible      = aw->ReadBool("AWNotebook", "Visible", true); // Visible
        cfgAWN_Left         = aw->ReadInteger("AWNotebook", "Left", 8); // Left
        cfgAWN_Top          = aw->ReadInteger("AWNotebook", "Top", 8); // Top
        cfgAWN_Height       = aw->ReadInteger("AWNotebook", "Height", 273); // Height
        cfgAWN_Width        = aw->ReadInteger("AWNotebook", "Width", 481); // Width
        cfgAWN_Color        = aw->ReadString("AWNotebook", "Color", "$09000015"); // Color
        // []






        
        GlPRMImgRatingPath



        // Checking PRM`s path defined in External->PRM1Path
        if(GlPRMPath!=CFG_PRM1Path && CFG_PRM1Path!="*" && CFG_PRM1Path!="") // Comparing GlPRMPath value with PRM`s path defined by PStruct developer (or Installation program).
        {                                                                    // Also remember that this code defining PRM`s path for program configuration, so PStruct developer may leave External->PRoutePath property void (or use "*" in value).
                mainsetts->WriteString("External", "PRM1Path", GlPRMPath);
        }


        // Defining route paths
        GlPRPath                        = ExtractFileDir(GlPRMPath) + "\\";
        GlPRWorldPath                   = GlPRPath + "WORLD\\";
        GlPRActsPath                    = GlPRPath + "ACTIVITIES\\";
        GlPREnvPath                     = GlPRPath + "ENVFILES\\";
        GlPREnvTexPath                  = GlPRPath + "ENVFILES\\TEXTURES\\";
        GlPRShapesPath                  = GlPRPath + "SHAPES\\";
        GlPRSoundsPath                  = GlPRPath + "SOUNDS\\";
        GlPRWorldPath                   = GlPRPath + "WORLD\\";
        GlPRTerrTexPath                 = GlPRPath + "TERRTEX\\";
        GlPRTerrTexSnowPath             = GlPRPath + "TERRTEX\\SNOW\\";
        GlPRTexturesPath                = GlPRPath + "TEXTURES\\";
        GlPRTexturesAutPath             = GlPRPath + "TEXTURES\\AUTUMN\\";
        GlPRTexturesAutSnowPath         = GlPRPath + "TEXTURES\\AUTUMNSNOW\\";
        GlPRTexturesNightPath           = GlPRPath + "TEXTURES\\NIGHT\\";
        GlPRTexturesSnowPath            = GlPRPath + "TEXTURES\\SNOW\\";
        GlPRTexturesSprPath             = GlPRPath + "TEXTURES\\SPRING\\";
        GlPRTexturesSprSnowPath         = GlPRPath + "TEXTURES\\SPRINGSNOW\\";
        GlPRTexturesWinPath             = GlPRPath + "TEXTURES\\WINTER\\";
        GlPRTexturesWinSnowPath         = GlPRPath + "TEXTURES\\WINTERSNOW\\";
        GlPRTilesPath                   = GlPRPath + "TILES\\";


        // Global constant values from configuration files
        // GlPRM1StdColor <mainsetts.ini>
        // Global error indicators (variables)
        GlFColorCorrectorErr = false;

        // Create ReportFile and write first entries...
        FILE *ReportFile = fopen(GlReportFile, "at"); // Creating ReportFile...
        // Writing first entries into ReportFile.
        fprintf(ReportFile, FWriteEntry("PRM1 started."));
        fprintf(ReportFile, FWriteEntry("Started Reporting."));
        fprintf(ReportFile, FWriteEntry("File: " + GlReportFile + "."));
        fprintf(ReportFile, FWriteEntry("Starting PRM1..."));
        fclose(ReportFile); // Closing the stream

}
//---------------------------------------------------------------------------
void __fastcall TMainForm::ExitSpeedButtonClick(TObject *Sender)
{
        FExitPRM(0);
}
//---------------------------------------------------------------------------


